@@ -1,22 +1,15 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* libe-book
- * Version: MPL 2.0 / LGPLv2.1+
+/*
+ * This file is part of the libe-book project.
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * Alternatively, the contents of this file may be used under the terms
- * of the GNU Lesser General Public License Version 2.1 or later
- * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
- * applicable instead of those above.
- *
- * For further information visit http://libebook.sourceforge.net
  */
 
 #include <algorithm>
 
-#include <libwpd-stream/libwpd-stream.h>
+#include <librevenge-stream/librevenge-stream.h>
 
 #include "libebook_utils.h"
 #include "EBOOKCharsetConverter.h"
@@ -251,7 +244,7 @@ LRFHeader::LRFHeader()
 {
 }
 
-LRFParser::LRFParser(WPXInputStream *const input, WPXDocumentInterface *const document)
+LRFParser::LRFParser(librevenge::RVNGInputStream *const input, librevenge::RVNGTextInterface *const document)
   : m_collector(document)
   , m_input(input)
   , m_header(new LRFHeader())
@@ -279,7 +272,7 @@ bool LRFParser::parse()
   return false;
 }
 
-bool LRFParser::isSupported(WPXInputStream *const input)
+bool LRFParser::isSupported(librevenge::RVNGInputStream *const input)
 {
   const unsigned char signature[] = { 'L', '\0', 'R', '\0', 'F', '\0' };
   unsigned long readBytes = 0;
@@ -338,7 +331,7 @@ void LRFParser::readThumbnail()
 
 void LRFParser::readObjectIndex()
 {
-  m_input->seek(m_header->objectIndexOffset, WPX_SEEK_SET);
+  m_input->seek(m_header->objectIndexOffset, librevenge::RVNG_SEEK_SET);
   for (uint64_t i = m_header->numberOfObjects; 0 != i; --i)
   {
     unsigned id = readU32(m_input);
@@ -372,7 +365,7 @@ void LRFParser::readObject(const unsigned id, const unsigned type)
     EBOOK_DEBUG_MSG(("object %x has already been read\n", id));
   }
 
-  m_input->seek(entry.offset, WPX_SEEK_SET);
+  m_input->seek(entry.offset, librevenge::RVNG_SEEK_SET);
 
   const unsigned startTag = readU16(m_input);
   if (TAG_OBJECT_START != startTag)
@@ -504,7 +497,7 @@ void LRFParser::readObject(const unsigned id, const unsigned type)
   entry.read = true;
 }
 
-void LRFParser::readPageTreeObject(WPXInputStream *const object)
+void LRFParser::readPageTreeObject(librevenge::RVNGInputStream *const object)
 {
   bool readAnyPage = false;
   if (TAG_PAGE_LIST == readU16(object))
@@ -522,7 +515,7 @@ void LRFParser::readPageTreeObject(WPXInputStream *const object)
   }
 }
 
-void LRFParser::readPageObject(WPXInputStream *const object)
+void LRFParser::readPageObject(librevenge::RVNGInputStream *const object)
 {
   unsigned pageAtrID = 0;
   LRFAttributes attributes;
@@ -530,7 +523,7 @@ void LRFParser::readPageObject(WPXInputStream *const object)
   unsigned streamSize = 0;
   const unsigned char *streamData = 0;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     switch (tag)
@@ -581,7 +574,7 @@ void LRFParser::readPageObject(WPXInputStream *const object)
   if (0 == streamFlags)
   {
     EBOOKMemoryStream strm(streamData, streamSize);
-    while (!strm.atEOS())
+    while (!strm.isEnd())
     {
       const unsigned tag = readU16(&strm);
       if (TAG_LINK == tag)
@@ -599,25 +592,25 @@ void LRFParser::readPageObject(WPXInputStream *const object)
   m_collector.closePage();
 }
 
-void LRFParser::readFooterObject(WPXInputStream *const object)
+void LRFParser::readFooterObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Footer is not supported yet\n"));
 }
 
-void LRFParser::readHeaderObject(WPXInputStream *const object)
+void LRFParser::readHeaderObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Header is not supported yet\n"));
 }
 
-void LRFParser::readPageAtrObject(WPXInputStream *const object, const unsigned id)
+void LRFParser::readPageAtrObject(librevenge::RVNGInputStream *const object, const unsigned id)
 {
   LRFAttributes attributes;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     if (!readAttribute(tag, object, attributes))
@@ -627,7 +620,7 @@ void LRFParser::readPageAtrObject(WPXInputStream *const object, const unsigned i
   m_collector.collectPageAttributes(id, attributes);
 }
 
-void LRFParser::readBlockObject(WPXInputStream *const object)
+void LRFParser::readBlockObject(librevenge::RVNGInputStream *const object)
 {
   unsigned blockAtrID = 0;
   LRFAttributes attributes;
@@ -635,7 +628,7 @@ void LRFParser::readBlockObject(WPXInputStream *const object)
   unsigned streamSize = 0;
   const unsigned char *streamData = 0;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     switch (tag)
@@ -677,7 +670,7 @@ void LRFParser::readBlockObject(WPXInputStream *const object)
   if (0 == streamFlags)
   {
     EBOOKMemoryStream strm(streamData, streamSize);
-    while (!strm.atEOS())
+    while (!strm.isEnd())
     {
       const unsigned tag = readU16(&strm);
       if (TAG_LINK == tag)
@@ -695,11 +688,11 @@ void LRFParser::readBlockObject(WPXInputStream *const object)
   m_collector.closeBlock();
 }
 
-void LRFParser::readBlockAtrObject(WPXInputStream *const object, const unsigned id)
+void LRFParser::readBlockAtrObject(librevenge::RVNGInputStream *const object, const unsigned id)
 {
   LRFAttributes attributes;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     if (!readAttribute(tag, object, attributes))
@@ -709,21 +702,21 @@ void LRFParser::readBlockAtrObject(WPXInputStream *const object, const unsigned
   m_collector.collectBlockAttributes(id, attributes);
 }
 
-void LRFParser::readMiniPageObject(WPXInputStream *const object)
+void LRFParser::readMiniPageObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Mini Page is not supported yet\n"));
 }
 
-void LRFParser::readBlockListObject(WPXInputStream *const object)
+void LRFParser::readBlockListObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Block List is not supported yet\n"));
 }
 
-void LRFParser::readTextObject(WPXInputStream *const object)
+void LRFParser::readTextObject(librevenge::RVNGInputStream *const object)
 {
   unsigned textAtrID = 0;
   LRFAttributes attributes;
@@ -732,7 +725,7 @@ void LRFParser::readTextObject(WPXInputStream *const object)
   const unsigned char *streamData = 0;
   unsigned textLength = 0;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     switch (tag)
@@ -777,7 +770,7 @@ void LRFParser::readTextObject(WPXInputStream *const object)
     m_collector.openTextBlock(textAtrID, attributes);
 
     // prepare text stream
-    boost::scoped_ptr<WPXInputStream> textStrm;
+    boost::scoped_ptr<librevenge::RVNGInputStream> textStrm;
 
     if (STREAM_TYPE_LRF_TAGS == streamFlags)
       textStrm.reset(new EBOOKMemoryStream(streamData, streamSize));
@@ -797,7 +790,7 @@ void LRFParser::readTextObject(WPXInputStream *const object)
     bool skipEOL = false;
     bool inParagraph = false;
 
-    while (!textStrm->atEOS())
+    while (!textStrm->isEnd())
     {
       const unsigned tag = readU16(textStrm.get());
 
@@ -834,7 +827,7 @@ void LRFParser::readTextObject(WPXInputStream *const object)
         EBOOKCharsetConverter utf16("UTF-16LE");
         EBOOKUTF8Stream utf8Strm(&memoryStrm, &utf16);
         std::string text;
-        while (!utf8Strm.atEOS())
+        while (!utf8Strm.isEnd())
           text.push_back(readU8(&utf8Strm));
 
         m_collector.collectText(text, textAttributes);
@@ -856,11 +849,11 @@ void LRFParser::readTextObject(WPXInputStream *const object)
   }
 }
 
-void LRFParser::readTextAtrObject(WPXInputStream *const object, const unsigned id)
+void LRFParser::readTextAtrObject(librevenge::RVNGInputStream *const object, const unsigned id)
 {
   LRFAttributes attributes;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     if (!readAttribute(tag, object, attributes))
@@ -870,14 +863,14 @@ void LRFParser::readTextAtrObject(WPXInputStream *const object, const unsigned i
   m_collector.collectTextAttributes(id, attributes);
 }
 
-void LRFParser::readImageObject(WPXInputStream *const object)
+void LRFParser::readImageObject(librevenge::RVNGInputStream *const object)
 {
   unsigned x = 0;
   unsigned y = 0;
   unsigned width = 0;
   unsigned height = 0;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
 
@@ -914,18 +907,18 @@ void LRFParser::readImageObject(WPXInputStream *const object)
   }
 }
 
-void LRFParser::readCanvasObject(WPXInputStream *const object)
+void LRFParser::readCanvasObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Canvas is not supported yet\n"));
 }
 
-void LRFParser::readParagraphAtrObject(WPXInputStream *const object, const unsigned id)
+void LRFParser::readParagraphAtrObject(librevenge::RVNGInputStream *const object, const unsigned id)
 {
   LRFAttributes attributes;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     if (!readAttribute(tag, object, attributes))
@@ -935,13 +928,13 @@ void LRFParser::readParagraphAtrObject(WPXInputStream *const object, const unsig
   m_collector.collectParagraphAttributes(id, attributes);
 }
 
-void LRFParser::readImageStreamObject(WPXInputStream *const object, const unsigned id)
+void LRFParser::readImageStreamObject(librevenge::RVNGInputStream *const object, const unsigned id)
 {
   unsigned streamType = 0;
   unsigned streamSize = 0;
   const unsigned char *streamData = 0;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
 
@@ -980,7 +973,7 @@ void LRFParser::readImageStreamObject(WPXInputStream *const object, const unsign
   case STREAM_TYPE_PNG :
   case STREAM_TYPE_BMP :
   {
-    WPXInputStream *image = new EBOOKMemoryStream(streamData, streamSize);
+    librevenge::RVNGInputStream *image = new EBOOKMemoryStream(streamData, streamSize);
     m_collector.collectImageData(id, static_cast<ImageType>(streamType), image);
     break;
   }
@@ -990,68 +983,68 @@ void LRFParser::readImageStreamObject(WPXInputStream *const object, const unsign
   }
 }
 
-void LRFParser::readImportObject(WPXInputStream *const object)
+void LRFParser::readImportObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Import is not supported yet\n"));
 }
 
-void LRFParser::readButtonObject(WPXInputStream *const object)
+void LRFParser::readButtonObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Button is not supported yet\n"));
 }
 
-void LRFParser::readWindowObject(WPXInputStream *const object)
+void LRFParser::readWindowObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Window is not supported yet\n"));
 }
 
-void LRFParser::readPopUpWinObject(WPXInputStream *const object)
+void LRFParser::readPopUpWinObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Pop Up Win is not supported yet\n"));
 }
 
-void LRFParser::readSoundObject(WPXInputStream *const object)
+void LRFParser::readSoundObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Sound is not supported yet\n"));
 }
 
-void LRFParser::readPlaneStreamObject(WPXInputStream *const object)
+void LRFParser::readPlaneStreamObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Plane Stream is not supported yet\n"));
 }
 
-void LRFParser::readFontObject(WPXInputStream *const object)
+void LRFParser::readFontObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Font is not supported yet\n"));
 }
 
-void LRFParser::readObjectInfoObject(WPXInputStream *const object)
+void LRFParser::readObjectInfoObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Object Info is not supported yet\n"));
 }
 
-void LRFParser::readBookAtrObject(WPXInputStream *const object)
+void LRFParser::readBookAtrObject(librevenge::RVNGInputStream *const object)
 {
   LRFAttributes attributes;
   unsigned pageTree = 0;
 
-  while (!object->atEOS())
+  while (!object->isEnd())
   {
     const unsigned tag = readU16(object);
     switch (tag)
@@ -1075,21 +1068,21 @@ void LRFParser::readBookAtrObject(WPXInputStream *const object)
   readObject(pageTree, OBJECT_TYPE_PAGE_TREE);
 }
 
-void LRFParser::readSimpleTextObject(WPXInputStream *const object)
+void LRFParser::readSimpleTextObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type Simple Text is not supported yet\n"));
 }
 
-void LRFParser::readTOCObject(WPXInputStream *const object)
+void LRFParser::readTOCObject(librevenge::RVNGInputStream *const object)
 {
   // TODO: implement me
   (void) object;
   EBOOK_DEBUG_MSG(("object type TOC is not supported yet\n"));
 }
 
-bool LRFParser::readAttribute(const unsigned tag, WPXInputStream *const input, LRFAttributes &attributes)
+bool LRFParser::readAttribute(const unsigned tag, librevenge::RVNGInputStream *const input, LRFAttributes &attributes)
 {
   bool handled = true;
 
@@ -1185,7 +1178,7 @@ bool LRFParser::readAttribute(const unsigned tag, WPXInputStream *const input, L
   return handled;
 }
 
-void LRFParser::skipUnhandledTag(const unsigned tag, WPXInputStream *const input, const char *const objectType)
+void LRFParser::skipUnhandledTag(const unsigned tag, librevenge::RVNGInputStream *const input, const char *const objectType)
 {
   switch (tag)
   {
@@ -1344,7 +1337,7 @@ void LRFParser::skipUnhandledTag(const unsigned tag, WPXInputStream *const input
 
   case TAG_OBJECT_START :
     EBOOK_DEBUG_MSG(("Object Start tag should never appear\n"));
-    // fall-through intended
+  // fall-through intended
   case TAG_F529 :
   case TAG_F5F9 :
     skip(input, 6);
@@ -1386,10 +1379,10 @@ void LRFParser::skipUnhandledTag(const unsigned tag, WPXInputStream *const input
   {
     // try to find the next tag
     unsigned n = 1;
-    while (!input->atEOS() && ((0xf5 != readU8(input)) || (2 <= n)))
+    while (!input->isEnd() && ((0xf5 != readU8(input)) || (2 <= n)))
       ++n;
-    if (!input->atEOS())
-      input->seek(-2, WPX_SEEK_CUR);
+    if (!input->isEnd())
+      input->seek(-2, librevenge::RVNG_SEEK_CUR);
   }
   break;
   default :
